@@ -5,7 +5,7 @@ use utf8;
 use parent qw(Exporter);
 our @EXPORT = (@Test::More::EXPORT, qw/filters blocks register_filter run run_is run_is_deeply/);
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 use parent qw/
     Test::Base::Less
@@ -145,7 +145,7 @@ __END__
 
 =head1 NAME
 
-Test::Base::Less - Enables Test::Base to use subtest
+Test::Base::Less - Enables Test::Base using subtest
 
 =head1 SYNOPSIS
 
@@ -154,30 +154,109 @@ Test::Base::Less - Enables Test::Base to use subtest
     filters { input => [qw/eval/] };
     run {
         my $block = shift;
-        is($block->input, $block->expected);
+        is $block->input, $block->expected, $block->name;
     };
     done_testing;
 
     __DATA__
 
     ### subtest 1
-      === test 1-1
-      --- input:    4*2
-      --- expected: 8
+        === test 1-1
+        --- input:    4*2
+        --- expected: 8
 
-      === test 1-2
-      --- input :   3*3
-      --- expected: 9
+        === test 1-2
+        --- input :   3*3
+        --- expected: 9
 
     ### subtest 2
-      === test 2-1
-      --- input:    4*3
-      --- expected: 12
+        === test 2-1
+        --- input:    4*3
+        --- expected: 12
 
-=head1 DESCRIPTION
+=begin html
+
+<div><img src="http://cdn-ak.f.st-hatena.com/images/fotolife/C/Cside/20140116/20140116204246.png?1389872580"></div>
+
+=end html
 
 =head1 FUNCTIONS
 
+This module exports all Test::More's exportable functions, and following functions:
+
+=over 4
+
+=item filters(+{ } : HashRef);
+
+    filters {
+        input => [qw/eval/],
+    };
+
+Set a filter for the section name.
+
+=item run(\&subroutine)
+
+    run {
+        my $block = shift;
+        is $block->input, $block->expected, $block->name;
+    };
+
+Calls the sub for each block. It passes the current block object to the subroutine.
+
+=item run_is([data_name1, data_name2])
+
+    run_is input => 'expected';
+
+=item run_is_deeply([data_name1, data_name2])
+
+=item register_filter($name: Str, $code: CodeRef)
+
+Register a filter for $name using $code.
+
+=back
+
+=head1 DEFAULT FILTERS
+
+This module provides only few filters. If you want to add more filters, pull-reqs welcome.
+(I only merge a patch using no depended modules)
+
+=over 4
+
+=item eval
+
+eval() the code.
+
+=item chomp
+
+C<chomp()> the arguments.
+
+=item uc
+
+C<uc()> the arguments.
+
+=item trim
+
+Remove extra blank lines from the beginning and end of the data. This
+allows you to visually separate your test data with blank lines.
+
+=back
+
+=head1 REGISTER YOUR OWN FILTER
+
+You can register your own filter by following form:
+
+    use Digest::MD5 qw/md5_hex/;
+    Test::Base::Less::register_filter(md5_hex => \&md5_hex);
+
+=head1 USE CODEREF AS FILTER
+
+You can use a CodeRef as filter.
+
+    use Digest::MD5 qw/md5_hex/;
+    filters {
+        input => [\&md5_hex],
+    };
+
 =head1 SEE ALSO
 
 Most of code is taken from L<Test::Base::Less>.
